@@ -1,12 +1,5 @@
-# -*- coding: utf-8 -*-
-"""Preprocess module.
-
-API:
-* *preprocess* (function): Easy-to-use preprocessing tool.
-
-"""
-from .tokenize import sent_tokenize, word_tokenize
 from .stem import PorterStemmer
+from .tokenize import sent_tokenize, word_tokenize
 
 
 def preprocess(corpus):
@@ -34,9 +27,7 @@ def preprocess(corpus):
     try:
         sents = sent_tokenize(corpus)
     except TypeError:
-        raise TypeError(
-            'Preprocess input must be string or a list of strings.'
-        )
+        raise TypeError("Preprocess input must be string or a list of strings.")
 
     stemmer = PorterStemmer()
     output = list()
