@@ -36,8 +36,10 @@ class RegexTagger(BaseTagger):
         """
         super().__init__(backoff)
 
-        if patterns == None:
-            self.patterns = {r'.*': 'token',}
+        if patterns is None:
+            self.patterns = {
+                r".*": "token",
+            }
         else:
             try:
                 for pattern in patterns.keys():
@@ -45,13 +47,13 @@ class RegexTagger(BaseTagger):
                 self.patterns = patterns
             except (AttributeError, TypeError):
                 raise TypeError(
-                    'Patterns must be dictionary containing string or compiled '
-                    'regex pattern as keys and strings as values.'
+                    "Patterns must be dictionary containing string or compiled "
+                    "regex pattern as keys and strings as values."
                 )
 
     def _token_tag(self, token):
         for pattern, tag in self.patterns.items():
-            if re.findall(pattern, token) != []:
+            if re.findall(pattern, token):
                 return tag
 
         return None
